Function std::intrinsics::copysignf32[−][src]

pub unsafe extern "rust-intrinsic" fn copysignf32(x: f32, y: f32) -> f32
🔬 This is a nightly-only experimental API. (core_intrinsics)

intrinsics are unlikely to ever be stabilized, instead they should be used through stabilized interfaces in the rest of the standard library

将 f32 值的符号从 y 复制到 x。

此内联函数的稳定版本是 f32::copysign