Function std::intrinsics::exact_div[−][src]

pub unsafe extern "rust-intrinsic" fn exact_div<T>(x: T, y: T) -> T where
    T: Copy, 
🔬 This is a nightly-only experimental API. (core_intrinsics)

intrinsics are unlikely to ever be stabilized, instead they should be used through stabilized interfaces in the rest of the standard library

执行精确除法,从而导致 x % y != 0 或 y == 0 或 x == T::MIN && y == -1 出现不确定的行为

此内联函数没有稳定的对应对象。